# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .dynamic_variables_config_dynamic_variable_placeholders_value import (
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class DynamicVariablesConfig(UncheckedBaseModel):
    dynamic_variable_placeholders: typing.Optional[
        typing.Dict[str, DynamicVariablesConfigDynamicVariablePlaceholdersValue]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
