# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
import typing
from .literal_json_schema_property import LiteralJsonSchemaProperty
import typing

if typing.TYPE_CHECKING:
    from .object_json_schema_property import ObjectJsonSchemaProperty
    from .array_json_schema_property import ArrayJsonSchemaProperty
ArrayJsonSchemaPropertyItems = typing.Union[
    LiteralJsonSchemaProperty, "ObjectJsonSchemaProperty", "ArrayJsonSchemaProperty"
]
