# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .tts_conversational_model import TtsConversationalModel
from .tts_output_format import TtsOutputFormat
from .tts_optimize_streaming_latency import TtsOptimizeStreamingLatency
from .pydantic_pronunciation_dictionary_version_locator import PydanticPronunciationDictionaryVersionLocator
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TtsConversationalConfig(UncheckedBaseModel):
    model_id: typing.Optional[TtsConversationalModel] = None
    voice_id: typing.Optional[str] = None
    agent_output_audio_format: typing.Optional[TtsOutputFormat] = None
    optimize_streaming_latency: typing.Optional[TtsOptimizeStreamingLatency] = None
    stability: typing.Optional[float] = None
    similarity_boost: typing.Optional[float] = None
    pronunciation_dictionary_locators: typing.Optional[typing.List[PydanticPronunciationDictionaryVersionLocator]] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
